@@ -60,13 +60,6 @@ class BuildController:
         if not res.status_code == 200:
             raise Exception(res.text)
 
-    @verify_credentials
-    def purge_account(self):
-        res = requests.delete(f'{self.account.hq}/account/purge', headers=self.account.headers)
-        if not res.status_code == 200:
-            raise Exception(res.text)
-        return res.text
-
     @verify_credentials
     def create_url(self, name: str):
         res = requests.get(f'{self.account.hq}/variant/{name}/url', headers=self.account.headers)
